from compress.installer import *
from compress.functions.main import *
from compress.functions.manage import *
from compress.functions.random import *
from compress.functions.time import *
from compress.functions.image import *